# -*- coding: UTF-8 -*-
textlist=[
	u"""بحمد الله ومنّته، أطلقنا اليوم واجهة سطح المكتب  لبرنامج مشكال لتشكيل النصوص العربية آليا مفتوح المصدر،
  وبهذا يتوفر حاليا تطبيقان للبرنامج على الوب .
 وعلى سطح المكتب لنظام وندوز. وسيتوفر لنظام لينكس.	
	""",
	u"""أسطورة أزمة المحتوى العربي على الإنترنت

حين تجرب، غير ما مرة، البحث بالعربية في الإنترنت ولا تجد ما يشبع حاجتك، تعرف بأن المحتوى العربي على الإنترنت يعاني نقصا فظيعا. لا تحتاج إلى جوجل أو غيرها لإخبارك بأن نسبة 1% التي يمثلها المحتوى العربي من مجموع المحتوى على الإنترنت، نسبة ضئيلة جدا. أنت تدرك ذلك منذ زمن، كما تدرك أنه قد مرت سنوات منذ سمعت أول مرة بأن المحتوى العربي على الإنترنت بالكاد يمثل تلك النسبة الهزيلة، ولا شيء تغير طيلة تلك السنوات. الكثير من الحبر سال حول الموضوع، وكثير من المؤتمرات انعقدت دون فائدة. المأساة أنك لو تتبعت تفاصيل تلك المؤتمرات التي تتحدث عن أزمة المحتوى العربي، لوجدت كل المتحدثين فيها يرطنون حول الموضوع بالانجليزية. ولا شك، أنك لو حاولت تبادل الحديث مع أحدهم، ولو في الشارع في موضوع عام، لما وجدته قادرا على تركيب جملة عربية خالصة لا تدخلها كلمات إنجليزية -أو فرنسية- بمناسبة أو دونها.
محمد الساحلي
	
	""",
	u"""	أهم ميزة لمشكال أنه يقترح تشكيلا آليا للنص، ومن ثمّ يمكن للمستخدم أن يصحح التشكيل، إذا وجد به خطأ، أو لم يكن المقصود كذلك, وهذه الميزة تجعل من الإصدار الحالي التجريبي مساعدا للتشكيل أكثر من كونه تشكيلا آليا,
	""",
	u"""تشكيل النصوص العربية أهم مسائل معالجة اللغة العربية، بلوغه يقتضي تجاوز عقبات عديدة، وقد أهمّت هذه المسألة الكثير من الباحثين، وحتى الشركات	
	""",
	u"""	أهم ميزة لمشكال أنه يقترح تشكيلا آليا للنص، ومن ثمّ يمكن للمستخدم أن يصحح التشكيل، إذا وجد به خطأ، أو لم يكن المقصود كذلك, وهذه الميزة تجعل من الإصدار الحالي التجريبي مساعدا للتشكيل أكثر من كونه تشكيلا آليا,
	""",
	u"""
يقدم البرنامج وظيفة نادرة لخدمة اللغة العربية ( لغة القرآن ) فهو يساعد المستخدم لتشكيل النص ، حيث يقوم البرنامج بمعالجة النص بعد وضعه في المربع المخصص له ووضع التشكيل عليه ( الفتحة والضمة والكسرة و.... الخ ) ومن ثم يمكن للمستخدم النقر على أي كلمة لتصحيح التشكيل وتغييره إذا كان فيه خطأ

البرنامج هو مساعد لعملية التشكيل أكثر منه مشكل آلي ، حيث لا غنى عن معرفة المستخدم في تصحيح بعض الأخطاء وتعديل التشكيل في بعض الكلمات ، لكن مسألة التشكيل ستكون سهلة وسريعة ومريحة جدا للمستخدم العربي بواسطة هذا البرنامج
	
	"""
,

	u"الولد مريض.",
	u"الطائر فوق الشجرة.",
	u"البستان جميل.",
	u"قطف محمد زهرة.",
	u"الشمس طالعة.",
	u"شم علي وردة.",
	u"يعيش السمك في الماء.",
	u"يكثر النخيل في مصر.",
	u"السماء ممطرة.",
	u"الحديقة جميلة.",
	u"يقطف علي الأزهار.",
	u"يلعب الغلمان بالكرة.",
	u"ينزل المطر من السماء .",
	u"يسير السحاب.",
	u"تطلع الشمس .",
	u"تسير السفن في البحار.",
	u"تجف الأرض .",
	u"يشتد البرد في الجبال.",
	u"الثوب نظيف.",
	u"القطار سريع.",
	u"العصفور في القفص .",
	u"الولد يأكل الفاكهة .",
	u"الثور يحرث الأرض .",
	u"القمر في السماء.",
	u"ركب إبراهيم الحصان .",
	u"سمعت النصيحة.",
	u"يداعب إسماعيل القط.",
	u"يسطع النور في الحجرة .",
	u"يحصد الفلاح القمح.",
	u"تجري السفينة على الماء.",
	u"تأكل الشاة فولا وشعيرا .",
	u"هل تحب السفر.",
	u"فريد يجري في الشارع.",
	u"يحب الولد البرتقال.",
	u"علي يركب الحمار.",
	u"يحترق الحطب.",
	u"الكلب ينام في البستان.",
	u"يتسلق الغلمان الجبل.",
	u"افترس الذئب كبشا.",
	u"يسبح الأولاد في البحار.",
	u"البستاني يجمع الأزهار.",
	u"المداد في الدواة.",
	u"الثعلب يأكل الدجاج.",
	u"الحديد يذوب في النار.",
	u"يفتح محمد الباب.",
	u"الثمر يتساقط على الأرض.",
	u"يشتري التاجر القطن.",
	u"يزرع الفلاح القصب.",
	u"تصنع الأحذية من الجلد.",
	u"يقرأ سعيد الكتاب.",
	u"العصفور يغرد على الشجرة.",
	u"يدخل الهواء في الحجرة.",
	u"يذهب العمال إلى المصنع.",
	u"العصفور مسجون في القفص.",
	u"تبيض الدجاجة.",
	u"يقرأ محمد كتابا.",
	u"يطيع أحمد أباه.",
	u"الحصان يجر العربة.",
	u"يشتد الحر في الصيف.",
	u"الفأر يخاف من الهر.",
	u"الحصان يأكل الشعير.",
	u"المريض يرجو الشفاء.",
	u"الولد يلعب بالكرة.",
	u"كسر محمود الغصن.",
	u"يصنع النجار بابا.",
	u"الطبيب يعالج المريض.",
	u"الخادم يفتح النافذة.",
	u"يسبح الغلام في النهر.",
	u"يعود الغريب إلى بلده.",
	u"يذهب التلميذ إلى المدرسة.",
	u"نام الطفل على السرير.",
	u"قطعت الحبل بالسكين.",
	u"يرضى المعلم عن التلميذ المؤدب.",
	u"جرى الكلب.",
	u"وقف الرجل.",
	u"دقت الساعة.",
	u"جاءت البنت.",
	u"ضاع الكتاب.",
	u"باضت الدجاجة.",
	u"أغسل يدي.",
	u"ينبح الكلب.",
	u"ألبس ثيابي.",
	u"ينتبه الحارس.",
	u"يلعب بالكرة.",
	u"تأكل البنت.",
	u"نمشي في الحقول.",
	u"تذبل الوردة.",
	u"العب بالكرة.",
	u"نم مبكرا.",
	u"أطعم قطك.",
	u"تمهل في السير.",
	u"نظف ثيابك.",
	u"أجد مضغ الطعام.",
	u"جنى الفلاح قطنه وباعه ثم اشترى ببعض ثمنه ما يحتاج إليه.",
	u"نظر الطفل إلى الطائر وهو يحلق في السماء.",
	u"هبت العواصف ليلا فأطفأت المصابيح واقتلعت الأشجار.",
	u"سطا الذئب على الغنم فافترس واحدة وفر هاربا.",
	u"ادخل البستان ومتع نفسك بمنظره ، ولا تعبث بأزهاره وثماره.",
	u"لا تكثر من الكلام ، ولا تنطق بما لا تعلم.",
	u"اغسل يديك قبل الأكل وبعده ، ونظف أسنانك ، ولا تدخل الطعام على الطعام.",
	u"الفأرة تخاف من القط.",
	u"الدجاجة تبيض كل يوم بيضة.",
	u"الكلب يركض وراء صاحبه.",
	u"الأم تطعم أولادها.",
	u"الولد أراد الجلوس.",
	u"الخادم نظف الغرفة.",
	u"الرجل سبح في النهر.",
	u"علي سافر إلى فرنسا.",
	u"سار القطار.",
	u"مرض الغلام.",
	u"طار الصقر.",
	u"نزل المطر.",
	u"سافر والدي.",
	u"عطش الزرع .",
	u"يغرد العصفور.",
	u"يثمر البستان.",
	u"يبيع التاجر البن.",
	u"يغسل الولد يديه.",
	u"يجني الفلاح القطن.",
	u"أحترم المعلم.",
	u"أقرأ في الكتاب.",
	u"أحفظ الدرس.",
	u"أشتغل في الحديقة.",
	u"أنظف الحذاء.",
	u"أنطق بالصدق.",
	u"طار العصفور.",
	u"يعوم السمك.",
	u"جرى الحصان.",
	u"يلسع البعوض.",
	u"لعب الولد.",
	u"تأكل البنت.",
	u"حضر الغائب.",
	u"يطير الذباب.",
	u"فاض النهر.",
	u"يربح التاجر.",
	u"شد التلميذ الحبل.",
	u"يربح السابق جائزة.",
	u"طوت البنت الثوب.",
	u"يصيد الثعلب دجاجة.",
	u"أكل الذئب الخروف.",
	u"يبيع القصاب اللحم.",
	u"مزق الغلام الورق.",
	u"صنع النجار كرسيا.",
	u"حلبت الفتاة البقرة.",
	u"رمى الصياد الشبكة.",
	u"أيقظ الرعد النائم.",
	u"طبخت المرأة الطعام.",
	u"أكل الحمار الفول.",
	u"أبصر الرجل الهلال.",
	#نعت
	u" هذا كتاب مفيد .",
	u"قرأت كتابا مفيدا .",
	u"نظرت في كتاب مفيد .",
	u"هذا ميدان فسيح .",
	u"رأيت ميدانا فسيحا .",
	u"جريت في ميدان فسيح .",
	u"تفتحت الوردة الجميلة .",
	u"قطفت الوردة الجميلة .",
	u"نظرت إلى الوردة الجميلة .",
	u"الولد المهذب يحبه أبوه .",
	u"لا تشرب الماء الراكد .",
	u"الحذاء الجديد يضر القدم .",
	u"أكثر من القراءة في الكتب النافعة , زرت ضاحية بديعة.",
	u"يضر الصديق الكاذب صديقه .",
	u"للجمل عنق طويل .",
	u"عدو عاقل خير من صديق جاهل .",
	u"تنافسوا في العمل الصالح .",
	u"يحب الناس الحاكم العادل .",
	u"وضعت الصورة في إطار بديع .",
	u"الأكل الكثير يضر المعدة .",
	u"أكره السير في الطرق المزدحمة .",
	u"تحمل الشجرة ثمارا ناضجة .",
	u"في السماء نجوم لامعة .",
	u"للطاووس ريش جميل .",
	u"أرى في الجو سحابا كثيفا .",
	u"ربح التاجر الأمين .",
	u"يقرأ علي كتابا مفيدا .",
	u"نزل من السماء مطر غزير .",
	u"يلبس علي حذاء واسعا .",
	u"يكثر النخل في البساتين المثمرة .",
	#المبتدا والخبر 
	u"التفاحة حلوة .",
	u"الصورة جميلة .",
	u"القطار سريع .",
	u"النظافة واجبة .",
	u"الجري مفيد .",
	u"الأرض مستديرة .",
	u"الدواة مملوءة .",
	u"الهواء متجدد .",
	u"الحذاء جديد .",
	u"المزاح مضر .",
	u"التاجر أمين .",
	u"الحديقة فسيحة .",
	u"المعلم حاضر .",
	u"الفقير محتاج .",
	u"الشجرة مثمرة .",
	#الجملة الفعلية
	u" يفترس النمر .",
	u"تنضج الفاكهة .",
	u"يحضر المسافر .",
	u"يشتد الحر .",
	u"يسبح السمك .",
	u"يندم الكسلان .",
	u"السيارة سريعة .",
	u"القط ألوف .",
	u"لمع البرق .",
	u"يشتد البرد .",
	u"عوى الذئب .",
	u"اقطف الوردة .",
	u"خذ الكتاب .",
	#الجملة الاسمية 
	u"الدار واسعة .",
	u"الشارع مزدحم .",
	u"الجو معتدل .",
	u"الطريقة ضيقة .",
	u"الغبار ثائر .",
	u"الفأرة مختبئة .",
	u"الماء رائق .",
	u"يسرج الخادم الحصان .",
	u"يسقط الخادم .",
	u"الزجاج مكسور .",
	u"البرد قارس .",
	u"القط جائع .",
	u"يشتد الحر في الصيف .",
	u"جنى الفلاح القطن .",
	u"يجول التاجر في البلاد .",
	u"النوافذ مفتوحة .",
	u"تزدحم المدينة بالسكان .",
	u"الولد نائم .",
	u"الكتاب نافع .",
	u"البحر هائج .",
	u"الشمس مشرقة .",
	u"المطر كثير .",
	u"الحجرة مظلمة .",
	u"ضاع المفتاح .",
	u"يثمر البستان .",
	u"أسرع القطار .",
	u"يغرد الطائر .",
	u"زاد النيل .",
	u"يضيء المصباح .",
	u"ما شكل البرتقالة ؟ ما لونها ؟.", 
	u"هل أكلت برتقالة ؟ كيف وجدت طعمها ؟ أناعمة هي أم خشنة ؟.", 
	u"بكم تشتري البرتقالة ؟.",
	#نصب الفعل المضارع 
	u"أريد أن أجيد السباحة .",
	u"أرجو أن يعتدل الجو .",
	u"لن أكتب .",
	u"لن يفوز الكسلان .",
	u"سرني أن تزورنا .",
	u"لن أضرب القط .",
	u"إذن تقيم عندنا .",
	u"إذن تربح تجارتك .",
	u"جئت كي أتعلم .",
	u"خرجت كي أتنزه .",
	u"أتعلم كي أخدم الوطن .",
	u"لن يبيع أبي حصانه.",
	u"هززت الشجرة كي يسقط ثمرها .",
	u"لا يجوز للإنسان أن يجلس في مجرى الهواء .",
	u"فتحت نوافذ الجحرة كي يتجدد هواؤها .",
	u"كن مؤدبا كي تكون محبوبا .",
	u"يشتغل الإنسان بالنهار وينام بالليل .",
	u"يجب عليك أن تنظف أسنانك كل يوم .",
	u"سأعتاد التبكير في النوم ، إذن يصح بدنك .",
	u"يقرأ سعيد في الضوء الضعيف .",
	u"يتعب الإنسان في صغره كي يرتاح في كبره .",
	u"يسرني أن تحضر .",
	u"يأكل الإنسان كي ينمو .",
	u"الحسود لن يسود .",
	u"على المسافر أن يتزود .",
	u"اشتريت منزلا كي أسكنه .",
	u"إن عدت إلى الذنب فلن أسامحك .",
	u"يحرث الفلاح الأرض كي يزرعها .",
	u"يرغب التاجر في أن يربح .",
	u"يؤلم العين أن تنظر إلى الشمس .",
	u"التلميذ الكسلان لن ينجح .",
	u"يصدق التاجر كي يرضي الله .",
	u"تبنى السجون كي يدخلها المجرمون .",
	u"لا يستطيع الأعمى أن يقرأ المكتوب .",
	u"أحب أن أسافر .",
	u"أسرعت كي أدرك القطار .",
	u"جئت كي أسلم عليك .",
	u"يؤلمني أن تعذب الحيوان .",
	u"يسرني أن أنجح .",
	u"أطاع كي يحبه أبوه .",
	u"لن يعود الغائب .",
	u"المذنب لن يعود إلى ذنبه .",
	u"محمد لن يتأخر في الصباح .",
	u"أخوك لن يتعرض للبرد .",
	u"لن أسافر وحدي .",
	u"لن أبطئ في المشي .",
	u"جلس الولد كي يستريح .",
	u"إذن يذهب التعب .",
	# جزم الفعل المضارع 
	u"لم يحفظ محمد درسه .",
	u"لا تأكل وأنت شبعان .",
	u"لم ينقطع نزول المطر .",
	u"لا تكثر من الضحك .",
	u"لم يقبض أحد على اللص .",
	u"لا تسرع في السير .",
	u"إن تفتح نوافذ الحجرة يتجدد هواؤها .",
	u"إن تجلس في مجرى الهواء تمرض .",
	u"إن يسافر أخوك تسافر معه .",
	u"غامت السماء ولم تمطر .",
	u"إن تقرب من النار تشعر بحرارتها .",
	u"لم يحضر علي البارحة .",
	u"إن تتلف شيئا لغيرك تدفع ثمنه .",
	u"لا تتعود كثرة المزاح .",
	u"إن تضرب قطا يخمشك .",
	u"لا تشرب وأنت تعب .",
	u"لا تبلع طعاما قبل أن تجيد مضغه .",
	u"العصفور لم يغرد .",
	u"مشيت كثيرا ولم أتعب .",
	u"لم يثمر البستان .",
	u"القطار لم يتأخر عن موعده .",
	u"لم يحضر محمد مع أخيه .",
	u"لم أتعلم السباحة .",
	u"لم أضيع وقتا في اللعب .",
	u"الفلاح لم يحلب بقرته .",
	u"لا تلوث يديك بالمداد .",
	u"لا تتلف أثاث المنزل .",
	u"لا تضرب من هو أصغر منك .",
	u"لا تأخذ ما ليس لك .",
	u"لا تشرب بعد الجري .",
	u"لا تلبس الملابس الضيقة .",
	u"لم يسافر محمد .",
	u"لا ترافق الأشرار .",
	u"لم يلعب الولد .",
	u"لا تعذب الحيوان .",
	u"لم يأكل القط .",
	u"لا تهمل دروسك .",
	u"لم ينكسر الزجاج .",
	u"لم يرسل الغائب رسالة إلى أهله .",
	u"لم يحرث الفلاح أرضه .",
	u"لا تشرب الماء الكدر .",
	u"لا تكذب .",
	#كان وأخواتها 
	u"الزحام شديد .",
	u"كان الزحام شديدا .",
	u"البيت نظيف .",
	u"كان البيت نظيفا .",
	u"الثوب قصير .",
	u"صار الثوب قصيرا .",
	u"البرد قارس .",
	u"صار البرد قارسا .",
	u"الخادم قوي .",
	u"ليس الخادم قويا .",
	u"العامل نشيط .",
	u"ليس العامل نشيطا .",
	u"النهم مريض .",
	u"أصبح النهم مريضا .",
	u"الجو ممطر .",
	u"أصبح الجو ممطرا .",
	u"العامل متعب .",
	u"أمسى العامل متعبا .",
	u"الزهر ذابل .",
	u"أمسى الزهر ذابلا .",
	u"الغمام كثيف .",
	u"أضحى الغمام كثيفا .",
	u"الشارع مزدحم .",
	u"أضحى الشارع مزدحما .",
	u"المطر غزير .",
	u"ظل المطر غزيرا .",
	u"المصباح متقد .",
	u"بات المصباح متقدا .",
	u"المريض متألم .",
	u"بات المريض متألما .",
	u"يصبح المداد جافا .",
	u"يبيت البحر هائجا .",
	u"يظل العامل مشتغلا .",
	u"يمسي الناجح مسرورا .",
	u"يضحي الشارع مزدحما .",
	u"أصبحت الغرفة نظيفة.",
	u"باتت البحيرة هائجة .",
	u"ظلت العاملة مشتغلة .",
	u"أمست الناجحة مسرورة .",
	u"أضحت المدينة مزدحمة .",
	u"تصبح الغرفة نظيفة .",
	u"تبيت البحيرة هائجة .",
	u"تظل العاملة مشتغلة .",
	u"تمسي الناجحة مسرورة .",
	u"تضحي المدينة مزدحمة .",
	#إن وأخواتها
	u" إن الجمل صبور .",
	u"إن الهرم قديم .",
	u"علمت أن الامتحان قريب .",
	u"يسرني أن الزهرة ناضرة .",
	u"كأن الكتاب أستاذ .",
	u"كأن القمر مصباح .",
	u"البيت جديد لكن الأثاث قديم .",
	u"شبت النار لكن الخسائر قليلة .",
	u"ليت الفاكهة ناضجة .",
	u"ليت القمر طالع .",
	u"لعل الكتاب رخيص.",
	u"لعل المريض نائم .",
	]
